# If you change the compiler, you would need to change the BuildRequires
# to match
%define compiler gcc
%define mpidir %{_libdir}/%{name}/%{version}-%{compiler}

Summary: OSU MVAPICH2 MPI package
License: BSD
Group: Development/Libraries
Name: mvapich2
Version: 1.0.3
Release: 3%{?dist}
Source: mvapich2-%{version}.tar.gz
Patch0: mvapich2-make.patch
URL: http://mvapich.cse.ohio-state.edu/
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: gcc-gfortran
BuildRequires: libibumad-devel libibverbs-devel librdmacm-devel
Requires: mpi-selector
Requires(post): mpi-selector, rpm
Requires(preun): mpi-selector, rpm
ExclusiveArch: i386 ia64 x86_64

%description
This is an MPI-2 implementation which includes all MPI-1 features.  It is
based on MPICH2 and MVICH.

%prep
%setup -q
%patch0 -p1 -b .make

%build
export OPEN_IB_HOME=%{_prefix}
export RDMA_CM_SUPPORT=yes
export PREFIX=%{mpidir}
export DESTDIR=%{buildroot}
export ROMIO=yes
export SHARED_LIBS=yes
export VCLUSTER=_MEDIUM_CLUSTER
export IO_BUS=_PCI_EX_
export LINKS=_DDR_
export F77=gfortran
%ifarch i386
export ARCH=_IA32_
%endif
%ifarch x86_64
export ARCH=_X86_64_
%endif
%ifarch ia64
export ARCH=_IA64_
%endif

./make.mvapich2.ofa

%install
rm -fr %{buildroot}
make DESTDIR=%{buildroot} install
cd %{buildroot}%{mpidir}

# create the mpivars.[c]sh files.
cat >bin/mpivars.csh <<EOF
if (\$?path) then
    if ( "\${path}" !~ *%{mpidir}/bin* ) then
	set path = ( %{mpidir}/bin \$path )
    endif
else
    set path = ( %{mpidir}/bin )
endif

if (\$?LD_CONFIG_PATH) then
    if ( "\${LD_CONFIG_PATH}" !~ *%{mpidir}/lib* ) then
	setenv LD_CONFIG_PATH %{mpidir}/lib:\$LD_CONFIG_PATH
    endif
else
    setenv LD_CONFIG_PATH %{mpidir}/lib:
endif

setenv MPD_BIN %{mpidir}/bin
EOF

cat >bin/mpivars.sh <<EOF
if ! echo \${PATH} | grep -q %{mpidir}/bin ; then
    PATH=%{mpidir}/bin:\${PATH}
fi

if ! echo \${LD_LIBRARY_PATH} | grep -q %{mpidir}/lib ; then
    LD_CONFIG_PATH=%{mpidir}/lib:\${LD_CONFIG_PATH}
fi

export MPD_BIN=%{mpidir}/bin
EOF

%clean
rm -rf %{buildroot}

%post
# It is safe to reregister the same setup at every upgrade/reinstall/etc.
mpi-selector --register %{name}-%{version}-%{compiler}-%{_arch} \
    --source-dir %{mpidir}/bin --yes >/dev/null 2>&1
# We can't fail
/bin/true

%preun
# Count how many copies of this particular package are currently installed,
# knowing that on upgrade the new package being installed is already in this
# list by the time we are run, and that we are in the list too as we aren't
# removed until after our scripts complete.  If our count comes back as just
# 1, then we are the last copy of this particular version and we need to
# remove our registration.  This is true regardless of wheter this is an
# upgrade or an erase.  Note: we have to keep our arch in the query too or
# else multilib installations throw this count off.
COUNT=`rpm -q %{name}-%{version}.%{_arch} | wc -l`
if [ $COUNT -eq 1 ]; then
    mpi-selector --unregister %{name}-%{version}-%{compiler}-%{_arch} \
            --yes >/dev/null 2>&1
fi
/bin/true

%files
%defattr(-,root,root,-)
%dir %{mpidir}
%{mpidir}/*

%changelog
* Thu Oct 16 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-3
- Make sure MPD_BIN is set in the mpivars files
- Related: bz466390

* Fri Oct 03 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-2
- Make scriptlets match mvapich
- Include a Requires(post) and Requires(preun) so installs work properly
- Resolves: bz465448

* Thu Sep 18 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-1
- Initial rhel5 package
- Resolves: bz451477

* Sun May 04 2008 Jonathan Perkins <perkinjo@cse.ohio-state.edu>
- Created initial MVAPICH2 1.0.3 SRPM with IB and iWARP support.

